@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>                      */
+/* Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>                      */
 
 #ifndef MAILIMPORTER_FILTER_SYLPHEED_H
 #define MAILIMPORTER_FILTER_SYLPHEED_H
@@ -32,17 +32,17 @@ class MAILIMPORTER_EXPORT FilterSylpheed : public Filter
 {
 public:
     FilterSylpheed();
-    ~FilterSylpheed();
+    ~FilterSylpheed() override;
 
-    static QString defaultSettingsPath();
-    static QString isMailerFound();
+    Q_REQUIRED_RESULT static QString defaultSettingsPath();
+    Q_REQUIRED_RESULT static QString isMailerFound();
 
     void import() override;
     virtual void importMails(const QString &maildir);
 
     /* return local mail dir from folderlist.xml*/
     virtual QString localMailDirPath();
-    virtual bool excludeFile(const QString &file);
+    Q_REQUIRED_RESULT virtual bool excludeFile(const QString &file);
     virtual QString defaultInstallFolder() const;
     virtual QString markFile() const;
 private:
